
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{column_poster}[2011/11/14 Poster with multiple columns]
\RequirePackage{xkeyval}

\newcounter{numcols}
\setcounter{numcols}{3}
\DeclareOptionX{numcols}[3]{\setcounter{numcols}{#1}}

% all other options go to the geometry package
\DeclareOptionX*{\PassOptionsToPackage{\CurrentOption}{geometry}}

\ProcessOptionsX

\LoadClass{article}
\RequirePackage{geometry}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% package imports

\usepackage{xcolor}
\usepackage{calc}
\usepackage{a0size}
\usepackage{flowfram}
\usepackage{titlesec}
\usepackage{pgf}
\usepackage{pgffor}
\usepackage{etoolbox}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% set font size choices

\renewcommand{\tiny}{\fontfamily{cmss}\fontsize{12}{14}\selectfont}
\renewcommand{\scriptsize}{\fontfamily{cmss}\fontsize{14.4}{18}\selectfont}   
\renewcommand{\footnotesize}{\fontfamily{cmss}\fontsize{17.28}{22}\selectfont}
\renewcommand{\small}{\fontfamily{cmss}\fontsize{20.74}{25}\selectfont}
\renewcommand{\normalsize}{\fontfamily{cmss}\fontsize{24.88}{30}\selectfont}
\renewcommand{\large}{\fontfamily{cmss}\fontsize{29.86}{37}\selectfont}
\renewcommand{\Large}{\fontfamily{cmss}\fontsize{35.83}{45}\selectfont}
\renewcommand{\LARGE}{\fontfamily{cmss}\fontsize{43}{54}\selectfont}
\renewcommand{\huge}{\fontfamily{cmss}\fontsize{51.6}{64}\selectfont}
\renewcommand{\Huge}{\fontfamily{cmss}\fontsize{61.92}{77}\selectfont}
\newcommand{\veryHuge}{\fontfamily{cmss}\fontsize{74.3}{93}\selectfont}
\newcommand{\VeryHuge}{\fontfamily{cmss}\fontsize{89.16}{112}\selectfont}
\newcommand{\VERYHuge}{\fontfamily{cmss}\fontsize{107}{134}\selectfont}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% set colors

%\definecolor{background}{RGB}{164,0,29} % Stanford cardinal red
%\definecolor{box}{RGB}{231,209,154}     % Stanford sandstone 
\definecolor{background}{RGB}{244,127,36}      % UIUC orange bold
\definecolor{boxbackground}{RGB}{244,127,36}   % UIUC orange bold
\definecolor{boxoutline}{RGB}{0,60,125}        % UIUC blue bold
\definecolor{textbackground}{RGB}{255,255,255} % white
\definecolor{textoutline}{RGB}{0,60,125}       % UIUC blue bold
%\definecolor{box}{RGB}{110,139,191} % UIUC blue pastel
%\definecolor{box}{RGB}{239,138,28}  % UIUC orange pastel

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% read out variables for position data

\newlength{\leftedgeodd}
\newlength{\leftedgeeven}
\newlength{\rightedgeodd}
\newlength{\rightedgeeven}
\newlength{\topedge}
\newlength{\bottomedge}

\computeleftedgeodd{\leftedgeodd}
\computeleftedgeeven{\leftedgeeven}
\computerightedgeodd{\rightedgeodd}
\computerightedgeeven{\rightedgeeven}
\computetopedge{\topedge}
\computebottomedge{\bottomedge}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% helper macro

\newcommand{\newsetlength}[2]{\newlength{#1}\setlength{#1}{#2}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% box geometry parameters

% title box parameters
\setlength{\titlewidth}{\textwidth}
\newsetlength{\titleheight}{10cm}
\newsetlength{\titlesep}{2cm}
\newsetlength{\titlex}{0pt}
\newsetlength{\logoheight}{0.4\titleheight}

% column box parameters
\newsetlength{\colsep}{2cm}
\newsetlength{\borderhoriz}{2cm}
\newsetlength{\bordervert}{3cm}
\newsetlength{\borderthickness}{3mm}

% section heading box parameters
\newsetlength{\sectionindent}{1cm}
\newsetlength{\sectionheight}{3cm}
\newsetlength{\sectionborderthickness}{3mm}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute remaining geometry for boxes

\newcounter{numcolsless1}
\setcounter{numcolsless1}{\value{numcols}}
\addtocounter{numcolsless1}{-1}

\newsetlength{\titley}{\textheight-\titleheight}

\newsetlength{\totalcolwidth}{\textwidth - \value{numcolsless1}\colsep}
\newsetlength{\colwidth}{\totalcolwidth/\value{numcols}}
\newsetlength{\colheight}{\textheight-\titleheight-\titlesep}
\newsetlength{\coltextwidth}{\colwidth - 2\borderhoriz}
\newsetlength{\coltextheight}{\colheight - 2\bordervert}

\newsetlength{\sectionwidth}{\coltextwidth - 2\sectionindent}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create box frames

% background box
\newstaticframe{\paperwidth}{\paperheight}{\leftedgeodd}{\bottomedge}[back]

% title and logos in title
\newstaticframe{\titlewidth}{\titleheight}{\titlex}{\titley}[title]
\newstaticframe{\titlewidth}{\titleheight}{\titlex}{\titley}[leftlogo]
\newstaticframe{\titlewidth}{\titleheight}{\titlex}{\titley}[rightlogo]

% column frames (looping doesn't seem to work here)
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz}{\bordervert}
\ifnumgreater{\value{numcols}}{1}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + \colwidth + \colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{2}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + 2\colwidth + 2\colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{3}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + 3\colwidth + 3\colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{4}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + 4\colwidth + 4\colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{5}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + 5\colwidth + 5\colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{6}{%
\newflowframe{\coltextwidth}{\coltextheight}{\borderhoriz + 6\colwidth + 6\colsep}{\bordervert}}{}
\ifnumgreater{\value{numcols}}{7}{\ClassError{column_poster}{Cannot have more than 7 columns}{}}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% section headings

\newcommand{\sectionformat}[1]{%
  \begin{pgfpicture}{0pt}{0pt}{\sectionwidth}{\sectionheight}
    \color{boxbackground}
    \pgfrect[fill]{\pgforigin}{\pgfpoint{\sectionwidth}{\sectionheight}}
    \color{boxoutline}
    \pgfsetlinewidth{\sectionborderthickness}
    \pgfrect[stroke]{\pgforigin}{\pgfpoint{\sectionwidth}{\sectionheight}}
    \color{black}
    \pgfputat{\pgfpoint{\sectionwidth/2}{\sectionheight/2}}{%
      \pgfbox[center,center]{#1}}
  \end{pgfpicture}}
\titleformat{\section}
            {\bf \Large} %\vspace{-0.8ex}}
            {}{0pt}{\sectionformat}
\titlespacing{\section}{\sectionindent}{1cm}{*4} % left, above, below

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% helper commands to draw frames around boxes

\newcommand{\posterframebox}[2]{%
  \color{textbackground}
  \pgfrect[fill]{#1}{#2}
  \color{textoutline}
  \pgfsetlinewidth{\borderthickness}
  \pgfrect[stroke]{#1}{#2}
  \color{black}}

\newcommand{\posterframeboxtextrelative}[2]{%
  \posterframebox{\pgfdiff{\pgfpoint{\leftedgeodd}{\bottomedge}}{#1}}{#2}}

\newcommand{\posterframecol}[1]{%
  \posterframeboxtextrelative{#1}{\pgfpoint{\colwidth}{\colheight}}}

\newcommand{\posterbackground}{%
  \begin{pgfpicture}{0pt}{0pt}{\paperwidth}{\paperheight}
    \color{background}
    \pgfrect[fill]{\pgforigin}{\pgfpoint{\paperwidth}{\paperheight}}
    \posterframeboxtextrelative{\pgfpoint{0pt}{\titley}}%
    {\pgfpoint{\titlewidth}{\titleheight}}
    \foreach \c in {0,...,\value{numcolsless1}}
    {\posterframecol{\pgfpoint{0pt + \c\colwidth + \c\colsep}{0pt}}}
  \end{pgfpicture}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% text layout parameters

\setlength{\parindent}{0em}
\setlength{\parskip}{2em}
\linespread{1.2}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% change various parameters for float layout

\makeatletter

\setlength\floatsep    {34\p@ \@plus 4\p@ \@minus 8\p@}
\setlength\textfloatsep{40\p@ \@plus 4\p@ \@minus 8\p@}
\setlength\intextsep   {38\p@ \@plus 8\p@ \@minus 8\p@}
\setlength\dblfloatsep    {28\p@ \@plus 4\p@ \@minus 8\p@}
\setlength\dbltextfloatsep{40\p@ \@plus 4\p@ \@minus 8\p@}
\setlength\@fptop{0\p@ \@plus 2fil}
\setlength\@fpsep{20\p@ \@plus 4fil}
\setlength\@fpbot{0\p@ \@plus 2fil}
\setlength\@dblfptop{0\p@ \@plus 2fil}
\setlength\@dblfpsep{20\p@ \@plus 4fil}
\setlength\@dblfpbot{0\p@ \@plus 2fil}

\makeatother

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% figure captions inset from text and smaller

\makeatletter

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\small \textbf{#1:} #2}%
  \ifdim \wd\@tempboxa >0.8\coltextwidth
    \centerline{\parbox[t]{0.8\coltextwidth}{\textbf{#1:} #2}}\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\makeatother

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
